"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.pinoLambdaDestination = void 0;
const stream_1 = require("stream");
const context_1 = require("./context");
const formatters_1 = require("./formatters");
/**
 * Custom destination stream for pino
 * @param options Options
 */
const pinoLambdaDestination = (options = {}) => {
    const writeable = new stream_1.Writable({
        defaultEncoding: 'utf8',
        write(chunk, encoding, callback) {
            const storageProvider = options.storageProvider || context_1.GlobalContextStorageProvider;
            const formatter = (options === null || options === void 0 ? void 0 : options.formatter) || new formatters_1.CloudwatchLogFormatter();
            const data = JSON.parse(chunk);
            const lambdaContext = storageProvider.getContext() || {};
            // format the combined request context and log data
            let output = formatter.format({ ...lambdaContext, ...data });
            // replace characters for proper formatting
            output = output.replace(/\n/, '\r');
            // final entry must end with carriage return
            output += '\n';
            if (options.streamWriter) {
                options.streamWriter(output);
            }
            else {
                process.stdout.write(output);
            }
            callback();
        },
    });
    return writeable;
};
exports.pinoLambdaDestination = pinoLambdaDestination;
