"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.CloudwatchLogFormatter = void 0;
const pino_1 = __importDefault(require("pino"));
const formatLevel = (level) => {
    var _a;
    if (typeof level === 'string') {
        return level.toLocaleUpperCase();
    }
    else if (typeof level === 'number') {
        return (_a = pino_1.default.levels.labels[level]) === null || _a === void 0 ? void 0 : _a.toLocaleUpperCase();
    }
    return level;
};
/**
 * Formats the log in native cloudwatch format and
 * mixes in the Lambda request context data
 * Default format for pino-lambda
 */
class CloudwatchLogFormatter {
    format(data) {
        const { awsRequestId, level, msg } = data;
        // extract parts for message format
        const time = new Date().toISOString();
        const levelTag = formatLevel(level);
        return `${time}${awsRequestId ? `\t${awsRequestId}` : ''}\t${levelTag}\t${msg}\t${JSON.stringify(data)}`;
    }
}
exports.CloudwatchLogFormatter = CloudwatchLogFormatter;
